@@ -24,10 +24,9 @@
 
 #include <QTimer>
 
-#include <KGenericFactory>
+#include <KPluginFactory>
 
 K_PLUGIN_FACTORY(PrintDFactory, registerPlugin<PrintManagerKded>();)
-K_EXPORT_PLUGIN(PrintDFactory("printmanager", "print-manager"))
 
 PrintManagerKded::PrintManagerKded(QObject *parent, const QVariantList &args) :
     KDEDModule(parent),
@@ -49,3 +48,5 @@ void PrintManagerKded::loadThread()
 {
     m_newPrinterNotification = new NewPrinterNotification;
 }
+
+#include "PrintManagerKded.moc"
